""" openconfig_if_types 

This module contains a set of interface type definitions that
are used across OpenConfig models. These are generally physical
or logical interfaces, distinct from hardware ports (which are
described by the OpenConfig platform model).

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class INTERFACETYPE(Identity):
    """
    Base identity from which interface types are derived.
    
    """
    _prefix = 'oc-ift'
    _revision = '2018-01-05'

    def __init__(self, ns="http://openconfig.net/yang/openconfig-if-types", pref="openconfig-if-types", tag="openconfig-if-types:INTERFACE_TYPE"):
        super().__init__(ns, pref, tag)


class IFETHERNET(INTERFACETYPE):
    """
    Ethernet interfaces based on IEEE 802.3 standards, as well
    as FlexEthernet
    
    """
    _prefix = 'oc-ift'
    _revision = '2018-01-05'

    def __init__(self, ns="http://openconfig.net/yang/openconfig-if-types", pref="openconfig-if-types", tag="openconfig-if-types:IF_ETHERNET"):
        super().__init__(ns, pref, tag)


class IFAGGREGATE(INTERFACETYPE):
    """
    An aggregated, or bonded, interface forming a
    Link Aggregation Group (LAG), or bundle, most often based on
    the IEEE 802.1AX (or 802.3ad) standard.
    
    """
    _prefix = 'oc-ift'
    _revision = '2018-01-05'

    def __init__(self, ns="http://openconfig.net/yang/openconfig-if-types", pref="openconfig-if-types", tag="openconfig-if-types:IF_AGGREGATE"):
        super().__init__(ns, pref, tag)


class IFLOOPBACK(INTERFACETYPE):
    """
    A virtual interface designated as a loopback used for
    various management and operations tasks.
    
    """
    _prefix = 'oc-ift'
    _revision = '2018-01-05'

    def __init__(self, ns="http://openconfig.net/yang/openconfig-if-types", pref="openconfig-if-types", tag="openconfig-if-types:IF_LOOPBACK"):
        super().__init__(ns, pref, tag)


class IFROUTEDVLAN(INTERFACETYPE):
    """
    A logical interface used for routing services on a VLAN.
    Such interfaces are also known as switch virtual interfaces
    (SVI) or integrated routing and bridging interfaces (IRBs).
    
    """
    _prefix = 'oc-ift'
    _revision = '2018-01-05'

    def __init__(self, ns="http://openconfig.net/yang/openconfig-if-types", pref="openconfig-if-types", tag="openconfig-if-types:IF_ROUTED_VLAN"):
        super().__init__(ns, pref, tag)


class IFSONET(INTERFACETYPE):
    """
    SONET/SDH interface
    
    """
    _prefix = 'oc-ift'
    _revision = '2018-01-05'

    def __init__(self, ns="http://openconfig.net/yang/openconfig-if-types", pref="openconfig-if-types", tag="openconfig-if-types:IF_SONET"):
        super().__init__(ns, pref, tag)


class IFTUNNELGRE4(INTERFACETYPE):
    """
    A GRE tunnel over IPv4 transport.
    
    """
    _prefix = 'oc-ift'
    _revision = '2018-01-05'

    def __init__(self, ns="http://openconfig.net/yang/openconfig-if-types", pref="openconfig-if-types", tag="openconfig-if-types:IF_TUNNEL_GRE4"):
        super().__init__(ns, pref, tag)


class IFTUNNELGRE6(INTERFACETYPE):
    """
    A GRE tunnel over IPv6 transport.
    
    """
    _prefix = 'oc-ift'
    _revision = '2018-01-05'

    def __init__(self, ns="http://openconfig.net/yang/openconfig-if-types", pref="openconfig-if-types", tag="openconfig-if-types:IF_TUNNEL_GRE6"):
        super().__init__(ns, pref, tag)






""" openconfig_network_instance_types 

Types associated with a network instance

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class NETWORKINSTANCETYPE(Identity):
    """
    A base identity which can be extended to indicate different
    types of network instance supported by a device.
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:NETWORK_INSTANCE_TYPE"):
        super().__init__(ns, pref, tag)


class ENDPOINTTYPE(Identity):
    """
    Specification of the type of endpoint that is being associated
    with a network instance
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:ENDPOINT_TYPE"):
        super().__init__(ns, pref, tag)


class LABELALLOCATIONMODE(Identity):
    """
    Base identity to be used to express types of label allocation
    strategies to be used within a network instance
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:LABEL_ALLOCATION_MODE"):
        super().__init__(ns, pref, tag)


class ENCAPSULATION(Identity):
    """
    On the wire encapsulations that can be used when
    differentiating network instances
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:ENCAPSULATION"):
        super().__init__(ns, pref, tag)


class SIGNALLINGPROTOCOL(Identity):
    """
    The signalling protocol that should be used to diseminate
    entries within a forwarding instance
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:SIGNALLING_PROTOCOL"):
        super().__init__(ns, pref, tag)


class DEFAULTINSTANCE(NETWORKINSTANCETYPE):
    """
    A special routing instance which acts as the 'default' or
    'global' routing instance for a network device.
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:DEFAULT_INSTANCE"):
        super().__init__(ns, pref, tag)


class L3VRF(NETWORKINSTANCETYPE):
    """
    A private Layer 3 only routing instance which is formed of
    one or more RIBs
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:L3VRF"):
        super().__init__(ns, pref, tag)


class L2VSI(NETWORKINSTANCETYPE):
    """
    A private Layer 2 only switch instance which is formed of
    one or more L2 forwarding tables
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:L2VSI"):
        super().__init__(ns, pref, tag)


class L2P2P(NETWORKINSTANCETYPE):
    """
    A private Layer 2 only forwarding instance which acts as
    a point to point connection between two endpoints
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:L2P2P"):
        super().__init__(ns, pref, tag)


class L2L3(NETWORKINSTANCETYPE):
    """
    A private Layer 2 and Layer 2 forwarding instance
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:L2L3"):
        super().__init__(ns, pref, tag)


class LOCAL(ENDPOINTTYPE):
    """
    A local interface which is being associated with the endpoint
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:LOCAL"):
        super().__init__(ns, pref, tag)


class REMOTE(ENDPOINTTYPE):
    """
    A remote interface which is being associated with the
    endpoint
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:REMOTE"):
        super().__init__(ns, pref, tag)


class PERPREFIX(LABELALLOCATIONMODE):
    """
    A label is to be allocated per prefix entry in the RIB for the
    network instance
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:PER_PREFIX"):
        super().__init__(ns, pref, tag)


class PERNEXTHOP(LABELALLOCATIONMODE):
    """
    A label is to be allocated per nexthop entry in the RIB for
    the network instance
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:PER_NEXTHOP"):
        super().__init__(ns, pref, tag)


class INSTANCELABEL(LABELALLOCATIONMODE):
    """
    A single label is to be used for the instance
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:INSTANCE_LABEL"):
        super().__init__(ns, pref, tag)


class MPLS(ENCAPSULATION):
    """
    Use MPLS labels to distinguish network instances on the wire
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:MPLS"):
        super().__init__(ns, pref, tag)


class VXLAN(ENCAPSULATION):
    """
    Use VXLAN (RFC7348) VNIs to distinguish network instances on
    the wire
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:VXLAN"):
        super().__init__(ns, pref, tag)


class LDP(SIGNALLINGPROTOCOL):
    """
    Use LDP\-based setup for signalling. Where the instance is
    a point\-to\-point service this refers to RFC4447 ('Martini')
    setup. Where the service is an L2VSI, or L2L3 instance it
    refers to RFC4762 LDP\-signalled VPLS instances
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:LDP"):
        super().__init__(ns, pref, tag)


class BGPVPLS(SIGNALLINGPROTOCOL):
    """
    Use BGP\-based signalling and autodiscovery for VPLS instances
    as per RFC4761
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:BGP_VPLS"):
        super().__init__(ns, pref, tag)


class BGPEVPN(SIGNALLINGPROTOCOL):
    """
    Use BGP\-based Ethernet VPN (RFC7432) based signalling for
    the network instance
    
    """
    _prefix = 'oc-ni-types'
    _revision = '2016-12-15'

    def __init__(self, ns="http://openconfig.net/yang/network-instance-types", pref="openconfig-network-instance-types", tag="openconfig-network-instance-types:BGP_EVPN"):
        super().__init__(ns, pref, tag)






""" openconfig_aaa_types 

This module defines shared types for data related to AAA
(authentication, authorization, accounting).

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class AAASERVERTYPE(Identity):
    """
    Base identity for types of AAA servers
    
    """
    _prefix = 'oc-aaa-types'
    _revision = '2018-04-12'

    def __init__(self, ns="http://openconfig.net/yang/aaa/types", pref="openconfig-aaa-types", tag="openconfig-aaa-types:AAA_SERVER_TYPE"):
        super().__init__(ns, pref, tag)


class SYSTEMDEFINEDROLES(Identity):
    """
    Base identity for system\_defined roles that can be assigned
    to users.
    
    """
    _prefix = 'oc-aaa-types'
    _revision = '2018-04-12'

    def __init__(self, ns="http://openconfig.net/yang/aaa/types", pref="openconfig-aaa-types", tag="openconfig-aaa-types:SYSTEM_DEFINED_ROLES"):
        super().__init__(ns, pref, tag)


class AAAACCOUNTINGEVENTTYPE(Identity):
    """
    Base identity for specifying events types that should be
    sent to AAA server for accounting
    
    """
    _prefix = 'oc-aaa-types'
    _revision = '2018-04-12'

    def __init__(self, ns="http://openconfig.net/yang/aaa/types", pref="openconfig-aaa-types", tag="openconfig-aaa-types:AAA_ACCOUNTING_EVENT_TYPE"):
        super().__init__(ns, pref, tag)


class AAAAUTHORIZATIONEVENTTYPE(Identity):
    """
    Base identity for specifying activities that should be
    sent to AAA server for authorization
    
    """
    _prefix = 'oc-aaa-types'
    _revision = '2018-04-12'

    def __init__(self, ns="http://openconfig.net/yang/aaa/types", pref="openconfig-aaa-types", tag="openconfig-aaa-types:AAA_AUTHORIZATION_EVENT_TYPE"):
        super().__init__(ns, pref, tag)


class AAAMETHODTYPE(Identity):
    """
    Base identity to define well\-known methods for AAA
    operations
    
    """
    _prefix = 'oc-aaa-types'
    _revision = '2018-04-12'

    def __init__(self, ns="http://openconfig.net/yang/aaa/types", pref="openconfig-aaa-types", tag="openconfig-aaa-types:AAA_METHOD_TYPE"):
        super().__init__(ns, pref, tag)


class SYSTEMROLEADMIN(SYSTEMDEFINEDROLES):
    """
    Built\-in role that allows the equivalent of superuser
    permission for all configuration and operational commands
    on the device.
    
    """
    _prefix = 'oc-aaa-types'
    _revision = '2018-04-12'

    def __init__(self, ns="http://openconfig.net/yang/aaa/types", pref="openconfig-aaa-types", tag="openconfig-aaa-types:SYSTEM_ROLE_ADMIN"):
        super().__init__(ns, pref, tag)


class AAAACCOUNTINGEVENTCOMMAND(AAAACCOUNTINGEVENTTYPE):
    """
    Specifies interactive command events for AAA accounting
    
    """
    _prefix = 'oc-aaa-types'
    _revision = '2018-04-12'

    def __init__(self, ns="http://openconfig.net/yang/aaa/types", pref="openconfig-aaa-types", tag="openconfig-aaa-types:AAA_ACCOUNTING_EVENT_COMMAND"):
        super().__init__(ns, pref, tag)


class AAAACCOUNTINGEVENTLOGIN(AAAACCOUNTINGEVENTTYPE):
    """
    Specifies login events for AAA accounting
    
    """
    _prefix = 'oc-aaa-types'
    _revision = '2018-04-12'

    def __init__(self, ns="http://openconfig.net/yang/aaa/types", pref="openconfig-aaa-types", tag="openconfig-aaa-types:AAA_ACCOUNTING_EVENT_LOGIN"):
        super().__init__(ns, pref, tag)


class AAAAUTHORIZATIONEVENTCOMMAND(AAAAUTHORIZATIONEVENTTYPE):
    """
    Specifies interactive command events for AAA authorization
    
    """
    _prefix = 'oc-aaa-types'
    _revision = '2018-04-12'

    def __init__(self, ns="http://openconfig.net/yang/aaa/types", pref="openconfig-aaa-types", tag="openconfig-aaa-types:AAA_AUTHORIZATION_EVENT_COMMAND"):
        super().__init__(ns, pref, tag)


class AAAAUTHORIZATIONEVENTCONFIG(AAAAUTHORIZATIONEVENTTYPE):
    """
    Specifies configuration (e.g., EXEC) events for AAA
    authorization
    
    """
    _prefix = 'oc-aaa-types'
    _revision = '2018-04-12'

    def __init__(self, ns="http://openconfig.net/yang/aaa/types", pref="openconfig-aaa-types", tag="openconfig-aaa-types:AAA_AUTHORIZATION_EVENT_CONFIG"):
        super().__init__(ns, pref, tag)


class TACACSALL(AAAMETHODTYPE):
    """
    The group of all TACACS+ servers.
    
    """
    _prefix = 'oc-aaa-types'
    _revision = '2018-04-12'

    def __init__(self, ns="http://openconfig.net/yang/aaa/types", pref="openconfig-aaa-types", tag="openconfig-aaa-types:TACACS_ALL"):
        super().__init__(ns, pref, tag)


class RADIUSALL(AAAMETHODTYPE):
    """
    The group of all RADIUS servers.
    
    """
    _prefix = 'oc-aaa-types'
    _revision = '2018-04-12'

    def __init__(self, ns="http://openconfig.net/yang/aaa/types", pref="openconfig-aaa-types", tag="openconfig-aaa-types:RADIUS_ALL"):
        super().__init__(ns, pref, tag)


class LOCAL(AAAMETHODTYPE):
    """
    Locally configured method for AAA operations.
    
    """
    _prefix = 'oc-aaa-types'
    _revision = '2018-04-12'

    def __init__(self, ns="http://openconfig.net/yang/aaa/types", pref="openconfig-aaa-types", tag="openconfig-aaa-types:LOCAL"):
        super().__init__(ns, pref, tag)






""" openconfig_aaa 

This module defines configuration and operational state data
related to authorization, authentication, and accounting (AAA)
management.

Portions of this model reuse data definitions or structure from
RFC 7317 \- A YANG Data Model for System Management

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error

from ydk.models.openconfig.openconfig_aaa_types import AAASERVERTYPE


class TACACS(AAASERVERTYPE):
    """
    Terminal Access Controller Access Control System (TACACS+)
    AAA server
    
    """
    _prefix = 'oc-aaa'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/aaa", pref="openconfig-aaa", tag="openconfig-aaa:TACACS"):
        super().__init__(ns, pref, tag)


class RADIUS(AAASERVERTYPE):
    """
    Remote Authentication Dial In User Service (RADIUS) AAA
    server
    
    """
    _prefix = 'oc-aaa'
    _revision = '2017-09-18'

    def __init__(self, ns="http://openconfig.net/yang/aaa", pref="openconfig-aaa", tag="openconfig-aaa:RADIUS"):
        super().__init__(ns, pref, tag)






""" openconfig_vlan 

This module defines configuration and state variables for VLANs,
in addition to VLAN parameters associated with interfaces

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class Vlans(_Entity_):
    """
    Container for VLAN configuration and state
    variables
    
    .. attribute:: vlan
    
        Configured VLANs keyed by id
    
        **type**: list of    :py:class:`Vlan<ydk.models.openconfig.openconfig_vlan.Vlans.Vlan>`
    
    """
    _prefix = 'oc-vlan'
    _revision = '2016-05-26'

    def __init__(self):
        super().__init__()
        self._top_entity = None

        self.yang_name = "vlans"
        self.yang_parent_name = "openconfig-vlan"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("vlan", ("vlan", Vlans.Vlan))])
        self._leafs = OrderedDict()

        self.vlan = YList(self)
        self._segment_path = lambda: "openconfig-vlan:vlans"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(Vlans, [], name, value)

    class Vlan(_Entity_):
        """
        Configured VLANs keyed by id
        
        .. attribute:: vlan_id  (key)
        
            references the configured vlan\-id
        
            **type**: int
        
                **range:** 1..4094
        
            **refers to**:  :py:class:`vlan_id<ydk.models.openconfig.openconfig_vlan.Vlans.Vlan.Config>`
        
        .. attribute:: config
        
            Configuration parameters for VLANs
        
            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_vlan.Vlans.Vlan.Config>`
        
        .. attribute:: state
        
            State variables for VLANs
        
            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_vlan.Vlans.Vlan.State>`
        
            **config**: False
        
        .. attribute:: members
        
            Enclosing container for list of member interfaces
        
            **type**:  :py:class:`Members<ydk.models.openconfig.openconfig_vlan.Vlans.Vlan.Members>`
        
        """
        _prefix = 'oc-vlan'
        _revision = '2016-05-26'

        def __init__(self):
            super().__init__()

            self.yang_name = "vlan"
            self.yang_parent_name = "vlans"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['vlan_id']
            self._child_classes = OrderedDict([("config", ("config", Vlans.Vlan.Config)), ("state", ("state", Vlans.Vlan.State)), ("members", ("members", Vlans.Vlan.Members))])
            self._leafs = OrderedDict([
                ('vlan_id', (YLeaf(YType.str, 'vlan-id'), ['int'])),
            ])
            self.vlan_id = None

            self.config = Vlans.Vlan.Config()
            self.config.parent = self
            self._children_name_map["config"] = "config"

            self.state = Vlans.Vlan.State()
            self.state.parent = self
            self._children_name_map["state"] = "state"

            self.members = Vlans.Vlan.Members()
            self.members.parent = self
            self._children_name_map["members"] = "members"
            self._segment_path = lambda: "vlan" + "[vlan-id='" + str(self.vlan_id) + "']"
            self._absolute_path = lambda: "openconfig-vlan:vlans/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Vlans.Vlan, ['vlan_id'], name, value)

        class Config(_Entity_):
            """
            Configuration parameters for VLANs
            
            .. attribute:: vlan_id
            
                Interface VLAN id
            
                **type**: int
            
                    **range:** 1..4094
            
            .. attribute:: name
            
                Interface VLAN name
            
                **type**: str
            
            .. attribute:: status
            
                Admin state of the VLAN
            
                **type**:  :py:class:`Status<ydk.models.openconfig.openconfig_vlan.Vlans.Vlan.Config.Status>`
            
                **default value**: ACTIVE
            
            .. attribute:: tpid
            
                Optionally set the tag protocol identifier field (TPID) that is accepted on the VLAN
            
                **type**:  :py:class:`TPIDTYPES<ydk.models.openconfig.openconfig_vlan_types.TPIDTYPES>`
            
                **default value**: oc-vlan-types:TPID_0x8100
            
            """
            _prefix = 'oc-vlan'
            _revision = '2016-05-26'

            def __init__(self):
                super().__init__()

                self.yang_name = "config"
                self.yang_parent_name = "vlan"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.openconfig.openconfig_vlan', 'Vlans', 'Vlan.Config.Status')])),
                    ('tpid', (YLeaf(YType.identityref, 'tpid'), [('ydk.models.openconfig.openconfig_vlan_types', 'TPIDTYPES')])),
                ])
                self.vlan_id = None
                self.name = None
                self.status = None
                self.tpid = None
                self._segment_path = lambda: "config"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Vlans.Vlan.Config, ['vlan_id', 'name', 'status', 'tpid'], name, value)

            class Status(Enum):
                """
                Status (Enum Class)

                .. data:: ACTIVE = 0

                    VLAN is active

                .. data:: SUSPENDED = 1

                    VLAN is inactive / suspended

                """

                ACTIVE = Enum.YLeaf(0, "ACTIVE")

                SUSPENDED = Enum.YLeaf(1, "SUSPENDED")



        class State(_Entity_):
            """
            State variables for VLANs
            
            .. attribute:: vlan_id
            
                Interface VLAN id
            
                **type**: int
            
                    **range:** 1..4094
            
                **config**: False
            
            .. attribute:: name
            
                Interface VLAN name
            
                **type**: str
            
                **config**: False
            
            .. attribute:: status
            
                Admin state of the VLAN
            
                **type**:  :py:class:`Status<ydk.models.openconfig.openconfig_vlan.Vlans.Vlan.State.Status>`
            
                **config**: False
            
                **default value**: ACTIVE
            
            .. attribute:: tpid
            
                Optionally set the tag protocol identifier field (TPID) that is accepted on the VLAN
            
                **type**:  :py:class:`TPIDTYPES<ydk.models.openconfig.openconfig_vlan_types.TPIDTYPES>`
            
                **config**: False
            
                **default value**: oc-vlan-types:TPID_0x8100
            
            """
            _prefix = 'oc-vlan'
            _revision = '2016-05-26'

            def __init__(self):
                super().__init__()

                self.yang_name = "state"
                self.yang_parent_name = "vlan"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.openconfig.openconfig_vlan', 'Vlans', 'Vlan.State.Status')])),
                    ('tpid', (YLeaf(YType.identityref, 'tpid'), [('ydk.models.openconfig.openconfig_vlan_types', 'TPIDTYPES')])),
                ])
                self.vlan_id = None
                self.name = None
                self.status = None
                self.tpid = None
                self._segment_path = lambda: "state"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Vlans.Vlan.State, ['vlan_id', 'name', 'status', 'tpid'], name, value)

            class Status(Enum):
                """
                Status (Enum Class)

                .. data:: ACTIVE = 0

                    VLAN is active

                .. data:: SUSPENDED = 1

                    VLAN is inactive / suspended

                """

                ACTIVE = Enum.YLeaf(0, "ACTIVE")

                SUSPENDED = Enum.YLeaf(1, "SUSPENDED")



        class Members(_Entity_):
            """
            Enclosing container for list of member interfaces
            
            .. attribute:: member
            
                List of references to interfaces / subinterfaces associated with the VLAN
            
                **type**: list of    :py:class:`Member<ydk.models.openconfig.openconfig_vlan.Vlans.Vlan.Members.Member>`
            
                **config**: False
            
            """
            _prefix = 'oc-vlan'
            _revision = '2016-05-26'

            def __init__(self):
                super().__init__()

                self.yang_name = "members"
                self.yang_parent_name = "vlan"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("member", ("member", Vlans.Vlan.Members.Member))])
                self._leafs = OrderedDict()

                self.member = YList(self)
                self._segment_path = lambda: "members"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Vlans.Vlan.Members, [], name, value)

            class Member(_Entity_):
                """
                List of references to interfaces / subinterfaces
                associated with the VLAN.
                
                .. attribute:: interface_ref
                
                    Reference to an interface or subinterface
                
                    **type**:  :py:class:`InterfaceRef<ydk.models.openconfig.openconfig_vlan.Vlans.Vlan.Members.Member.InterfaceRef>`
                
                    **config**: False
                
                """
                _prefix = 'oc-vlan'
                _revision = '2016-05-26'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "member"
                    self.yang_parent_name = "members"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-ref", ("interface_ref", Vlans.Vlan.Members.Member.InterfaceRef))])
                    self._leafs = OrderedDict()

                    self.interface_ref = Vlans.Vlan.Members.Member.InterfaceRef()
                    self.interface_ref.parent = self
                    self._children_name_map["interface_ref"] = "interface-ref"
                    self._segment_path = lambda: "member"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Vlans.Vlan.Members.Member, [], name, value)

                class InterfaceRef(_Entity_):
                    """
                    Reference to an interface or subinterface
                    
                    .. attribute:: state
                    
                        Operational state for interface\-ref
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_vlan.Vlans.Vlan.Members.Member.InterfaceRef.State>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-vlan'
                    _revision = '2016-05-26'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "interface-ref"
                        self.yang_parent_name = "member"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("state", ("state", Vlans.Vlan.Members.Member.InterfaceRef.State))])
                        self._leafs = OrderedDict()

                        self.state = Vlans.Vlan.Members.Member.InterfaceRef.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._segment_path = lambda: "interface-ref"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Vlans.Vlan.Members.Member.InterfaceRef, [], name, value)

                    class State(_Entity_):
                        """
                        Operational state for interface\-ref
                        
                        .. attribute:: interface
                        
                            Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                        
                            **type**: str
                        
                            **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                        
                            **config**: False
                        
                        .. attribute:: subinterface
                        
                            Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                        
                            **type**: int
                        
                                **range:** 0..4294967295
                        
                            **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-vlan'
                        _revision = '2016-05-26'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "interface-ref"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                            ])
                            self.interface = None
                            self.subinterface = None
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Vlans.Vlan.Members.Member.InterfaceRef.State, ['interface', 'subinterface'], name, value)






    def clone_ptr(self):
        self._top_entity = Vlans()
        return self._top_entity






""" openconfig_isis_lsdb_types 

This module contains general LSDB type definitions for use in
ISIS YANG model. 

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class ISISTLVTYPE(Identity):
    """
    Base identity for an ISIS TLV type.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:ISIS_TLV_TYPE"):
        super().__init__(ns, pref, tag)


class ISISSUBTLVTYPE(Identity):
    """
    Base identity for an ISIS SUB\-TLV type.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:ISIS_SUBTLV_TYPE"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYSUBTLVSTYPE(ISISSUBTLVTYPE):
    """
    Base identity for an ISIS TLV 22, 23, 222, 223, 141 SUB\-TLV
    type.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_SUBTLVS_TYPE"):
        super().__init__(ns, pref, tag)


class IPREACHABILITYSUBTLVSTYPE(ISISSUBTLVTYPE):
    """
    Base identity for an ISIS TLV 135, 235, 236, 237 SUB\-TLV
    type.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IP_REACHABILITY_SUBTLVS_TYPE"):
        super().__init__(ns, pref, tag)


class ROUTERCAPABILITYSUBTLVSTYPE(ISISSUBTLVTYPE):
    """
    Base identity for an ISIS TLV 242 SUB\-TLV type.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:ROUTER_CAPABILITY_SUBTLVS_TYPE"):
        super().__init__(ns, pref, tag)


class AREAADDRESSES(ISISTLVTYPE):
    """
    ISIS TLV 1. Intermediate System to Intermediate System Intra\-
    Domain Routeing Exchange Protocol for use in Conjunction with
    the Protocol for Providing the Connectionless\-mode Network
    Service (ISO 8473), International Standard 10589\: 2002, Second
    Edition, 2002.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:AREA_ADDRESSES"):
        super().__init__(ns, pref, tag)


class IISNEIGHBORS(ISISTLVTYPE):
    """
    ISIS TLV 2. Intermediate System to Intermediate System Intra\-
    Domain Routeing Exchange Protocol for use in Conjunction with
    the Protocol for Providing the Connectionless\-mode Network
    Service (ISO 8473), International Standard 10589\: 2002, Second
    Edition, 2002.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IIS_NEIGHBORS"):
        super().__init__(ns, pref, tag)


class INSTANCEID(ISISTLVTYPE):
    """
    ISIS TLV 7. An Instance Identifier (IID) to uniquely
    identify an IS\-IS instance. When the IID = 0, the list of
    supported ITIDs MUST NOT be present. An IID\-TLV with IID = 0
    MUST NOT appear in an SNP or LSP. When the TLV appears (with a
    non\-zero IID) in an SNP or LSP, exactly one ITID. MUST be
    present indicating the topology with which the PDU is
    associated. If no ITIDs or multiple ITIDs are present or the
    IID is zero, then the PDU MUST be ignored
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:INSTANCE_ID"):
        super().__init__(ns, pref, tag)


class AUTHENTICATION(ISISTLVTYPE):
    """
    ISIS TLV 10.Intermediate System to Intermediate System Intra\-
    Domain Routeing Exchange Protocol for use in Conjunction with
    the Protocol for Providing the Connectionless\-mode Network
    Service (ISO 8473) International Standard 10589\: 2002, Second
    Edition, 2002.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:AUTHENTICATION"):
        super().__init__(ns, pref, tag)


class PURGEOI(ISISTLVTYPE):
    """
    ISIS TLV 13. If an IS generates a purge, it SHOULD include
    this TLV in the purge with its own system ID.  If an IS
    receives a purge that does not include this TLV, then it SHOULD
    add this TLV with both its own system ID and the system ID of
    the IS from which it received the purge.  This allows ISs
    receiving purges to log the system ID of the originator, or the
    upstream source of the purge.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:PURGE_OI"):
        super().__init__(ns, pref, tag)


class LSPBUFFERSIZE(ISISTLVTYPE):
    """
    ISIS TLV 14. The maximum MTU that the advertising system can
    receive, expressed in bytes.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:LSP_BUFFER_SIZE"):
        super().__init__(ns, pref, tag)


class EXTENDEDISREACHABILITY(ISISTLVTYPE):
    """
    ISIS TLV 22. An extended IS reachability TLV that has a
    different data structure to TLV 2 that introduces the use of
    sub\-TLV object\-group.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:EXTENDED_IS_REACHABILITY"):
        super().__init__(ns, pref, tag)


class ISNEIGHBORATTRIBUTE(ISISTLVTYPE):
    """
    ISIS TLV 23. Identical in format to TLV 22 and included in
    Original LSPs or Extended LSPs. Regardless of the type of LSP
    in which the TLVs appear, the information pertains to the
    neighbor relationship between the Originating System and the IS
    identified in the TLV
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_NEIGHBOR_ATTRIBUTE"):
        super().__init__(ns, pref, tag)


class ISISALIASID(ISISTLVTYPE):
    """
    ISIS TLV 24. IS\-Alias TLV which extension\-capable ISs to
    recognize the Originating System of an Extended LSP set. It
    identifies the Normal system\-id of the Originating System
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:ISIS_ALIAS_ID"):
        super().__init__(ns, pref, tag)


class IPV4INTERNALREACHABILITY(ISISTLVTYPE):
    """
    ISIS TLV 128. TLV defines IP addresses within the routing
    domain reachable directly via one or more interfaces on this
    Intermediate system
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IPV4_INTERNAL_REACHABILITY"):
        super().__init__(ns, pref, tag)


class NLPID(ISISTLVTYPE):
    """
    ISIS TLV 129. TLV defines the set Network Layer Protocol
    Identifiers for Network Layer protocols that this Intermediate
    System is capable of relaying
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:NLPID"):
        super().__init__(ns, pref, tag)


class IPV4EXTERNALREACHABILITY(ISISTLVTYPE):
    """
    ISIS TLV 130. TLV defines IP addresses outside the routing
    domain reachable via interfaces on this Intermediate system.
    This is permitted to appear multiple times, and in an LSP with
    any LSP number. However, this field must not appear in
    pseudonode LSPs
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IPV4_EXTERNAL_REACHABILITY"):
        super().__init__(ns, pref, tag)


class IPV4INTERFACEADDRESSES(ISISTLVTYPE):
    """
    ISIS TLV 132. The IP address of one or more interfaces
    corresponding to the SNPAs enabled on this Intermediate system
    (i.e., one or more IP addresses of this router). This is
    permitted to appear multiple times, and in an LSP with any LSP
    number.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IPV4_INTERFACE_ADDRESSES"):
        super().__init__(ns, pref, tag)


class IPV4TEROUTERID(ISISTLVTYPE):
    """
    ISIS TLV 134. Traffic Engineering router ID TLV that contains
    the 4\-octet router ID of the router originating the LSP
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IPV4_TE_ROUTER_ID"):
        super().__init__(ns, pref, tag)


class EXTENDEDIPV4REACHABILITY(ISISTLVTYPE):
    """
    ISIS TLV 135. Extended IP reachability TLV that provides for a
    32\-bit metric and adds one bit to indicate that a prefix has
    been redistributed \_down\_ in the hierarchy
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:EXTENDED_IPV4_REACHABILITY"):
        super().__init__(ns, pref, tag)


class DYNAMICNAME(ISISTLVTYPE):
    """
    ISIS TLV 137. The Dynamic hostname TLV is optional.  This TLV
    may be present in any fragment of a non\-pseudonode LSP.  The
    value field identifies the symbolic name of the router
    originating the LSP.  This symbolic name can be the FQDN for the
    router, it can be a subset of the FQDN, or it can be any string
    operators want to use for the router.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:DYNAMIC_NAME"):
        super().__init__(ns, pref, tag)


class IPV4SRLG(ISISTLVTYPE):
    """
    ISIS TLV 138. IPv4 Shared Risk Link Group TLV
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IPV4_SRLG"):
        super().__init__(ns, pref, tag)


class IPV6SRLG(ISISTLVTYPE):
    """
    ISIS TLV 139. IPv6 Shared Risk Link Group
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IPV6_SRLG"):
        super().__init__(ns, pref, tag)


class IPV6TEROUTERID(ISISTLVTYPE):
    """
    ISIS TLV 140. The IPv6 TE Router ID TLV contains a 16\-octet
    IPv6 address. A stable global IPv6 address MUST be used, so that
    the router ID provides a routable address, regardless of the
    state of a node's interfaces. If a router does not implement
    traffic engineering, it MAY include or omit the IPv6 TE Router
    ID TLV.  If a router implements traffic engineering for IPv6, it
    MUST include this TLV in its LSP.  This TLV MUST NOT be included
    more than once in an LSP.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IPV6_TE_ROUTER_ID"):
        super().__init__(ns, pref, tag)


class MTISN(ISISTLVTYPE):
    """
    ISIS TLV 222. TLV is aligned with extended IS reachability TLV
    type 22 beside an additional two bytes in front at the beginning
    of the TLV that. indicate MT membership.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:MT_ISN"):
        super().__init__(ns, pref, tag)


class MTISNEIGHBORATTRIBUTE(ISISTLVTYPE):
    """
    ISIS TLV 223. Is is identical in format to TLV 222. In the
    event that there is a need to advertise in Extended LSPs such
    information associated with neighbors of the Originating System,
    it is necessary to define new TLVs to carry the sub\-TLV
    information.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:MT_IS_NEIGHBOR_ATTRIBUTE"):
        super().__init__(ns, pref, tag)


class MULTITOPOLOGY(ISISTLVTYPE):
    """
    ISIS TLV 229. This MT TLV can advertise up to 127 MTs.  It is
    announced in IIHs and LSP fragment 0, and can occur multiple
    times.  The resulting MT set SHOULD be the union of all the MT
    TLV occurrences in the packet. Any other IS\-IS PDU occurrence of
    this TLV MUST be ignored.  Lack of MT TLV in hellos and fragment
    zero LSPs MUST be interpreted as participation of the
    advertising interface or router in MT ID #0 only.  If a router
    advertises MT TLV, it has to advertise all the MTs it
    participates in, specifically including topology ID #0 also.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:MULTI_TOPOLOGY"):
        super().__init__(ns, pref, tag)


class IPV6INTERFACEADDRESSES(ISISTLVTYPE):
    """
    ISIS TLV 232. IPv6 Interface Address TLV that maps directly to
    the IP Interface Address TLV in [RFC1195]. We necessarily modify
    the contents to be 0\-15 16\-octet IPv6 interface addresses
    instead of 0\-63 4\-octet IPv4 interface addresses
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IPV6_INTERFACE_ADDRESSES"):
        super().__init__(ns, pref, tag)


class MTIPV4REACHABILITY(ISISTLVTYPE):
    """
    ISIS TLV 235. TLV is aligned with extended IP reachability TLV
    type 135 beside an additional two bytes in front to indicate MT
    membership
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:MT_IPV4_REACHABILITY"):
        super().__init__(ns, pref, tag)


class IPV6REACHABILITY(ISISTLVTYPE):
    """
    ISIS TLV 236. The IPv6 Reachability TLV describes network
    reachability through the specification of a routing prefix,
    metric information, a bit to indicate if the prefix is being
    advertised down from a higher level, a bit to indicate if the
    prefix is being distributed from another routing protocol, and
    OPTIONALLY the existence of Sub\-TLVs to allow for later
    extension.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IPV6_REACHABILITY"):
        super().__init__(ns, pref, tag)


class MTIPV6REACHABILITY(ISISTLVTYPE):
    """
    ISIS TLV 237. TLV is aligned with IPv6 Reachability TLV type
    236 beside an additional two bytes in front to indicate MT
    membership.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:MT_IPV6_REACHABILITY"):
        super().__init__(ns, pref, tag)


class ROUTERCAPABILITY(ISISTLVTYPE):
    """
    ISIS TLV 242. IS\-IS TLV named CAPABILITY, formed of multiple
    sub\-TLVs, which allows a router to announce its capabilities
    within an IS\-IS level or the entire routing domain.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:ROUTER_CAPABILITY"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYADMINGROUP(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 3. Administrative group(color).
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_ADMIN_GROUP"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYLINKID(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 4. Link Local/Remote Identifiers.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_LINK_ID"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYIPV4INTERFACEADDRESS(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 6. IPv4 Interface Address.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_IPV4_INTERFACE_ADDRESS"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYIPV4NEIGHBORADDRESS(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 8. IPv4 Neighbor Address.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_IPV4_NEIGHBOR_ADDRESS"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYMAXLINKBANDWIDTH(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 9. Maximum Link Bandwidth.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_MAX_LINK_BANDWIDTH"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYMAXRESERVABLEBANDWIDTH(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 10. Maximum Reservable Bandwidth.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_MAX_RESERVABLE_BANDWIDTH"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYUNRESERVEDBANDWIDTH(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 11. Unreserved bandwidth.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_UNRESERVED_BANDWIDTH"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYIPV6INTERFACEADDRESS(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 12. IPv6 Interface Address.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_IPV6_INTERFACE_ADDRESS"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYIPV6NEIGHBORADDRESS(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 13. IPv6 Neighbor Address.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_IPV6_NEIGHBOR_ADDRESS"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYEXTENDEDADMINGROUP(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 14. Extended Administrative Group.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_EXTENDED_ADMIN_GROUP"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYTEDEFAULTMETRIC(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 18. TE Default Metric.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_TE_DEFAULT_METRIC"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYLINKATTRIBUTES(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 19. Link Attributes.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_LINK_ATTRIBUTES"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYLINKPROTECTIONTYPE(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 20. Link Protection Type.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_LINK_PROTECTION_TYPE"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYBANDWIDTHCONSTRAINTS(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 22. Bandwidth Constraints.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_BANDWIDTH_CONSTRAINTS"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYUNCONSTRAINEDLSP(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 23. Unconstrained LSP.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_UNCONSTRAINED_LSP"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYADJSID(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 31. Adjacency Segment Identifier.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_ADJ_SID"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYADJLANSID(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 32. Adjacency LAN Segment Identifier.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_ADJ_LAN_SID"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYLINKDELAY(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 33. Unidirectional Link Delay.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_LINK_DELAY"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYMINMAXLINKDELAY(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 34. Min/Max Unidirectional Link Delay.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_MIN_MAX_LINK_DELAY"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYLINKDELAYVARIATION(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 35. Unidirectional Link Delay Variation.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_LINK_DELAY_VARIATION"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYLINKLOSS(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 36. Unidirectional Link Loss Delay.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_LINK_LOSS"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYRESIDUALBANDWIDTH(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 37. Unidirectional Residual Bandwidth.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_RESIDUAL_BANDWIDTH"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYAVAILABLEBANDWIDTH(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 38. Unidirectional Available Bandwidth.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_AVAILABLE_BANDWIDTH"):
        super().__init__(ns, pref, tag)


class ISREACHABILITYUTILIZEDBANDWIDTH(ISREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 39. Unidirectional Utilized Bandwidth.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IS_REACHABILITY_UTILIZED_BANDWIDTH"):
        super().__init__(ns, pref, tag)


class IPREACHABILITYTAG(IPREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 1. 32\-bit Administrative Tag.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IP_REACHABILITY_TAG"):
        super().__init__(ns, pref, tag)


class IPREACHABILITYTAG64(IPREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 2. 64\-bit Administrative Tag.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IP_REACHABILITY_TAG64"):
        super().__init__(ns, pref, tag)


class IPREACHABILITYPREFIXSID(IPREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 3. Prefix Segment Identifier.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IP_REACHABILITY_PREFIX_SID"):
        super().__init__(ns, pref, tag)


class IPREACHABILITYPREFIXFLAGS(IPREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 4. Prefix Attribute Flags.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IP_REACHABILITY_PREFIX_FLAGS"):
        super().__init__(ns, pref, tag)


class IPREACHABILITYIPV4ROUTERID(IPREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 11. IPv4 Source Router ID.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IP_REACHABILITY_IPV4_ROUTER_ID"):
        super().__init__(ns, pref, tag)


class IPREACHABILITYIPV6ROUTERID(IPREACHABILITYSUBTLVSTYPE):
    """
    sub\-TLV 12. IPv6 Source Router ID.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:IP_REACHABILITY_IPV6_ROUTER_ID"):
        super().__init__(ns, pref, tag)


class ROUTERCAPABILITYSRCAPABILITY(ROUTERCAPABILITYSUBTLVSTYPE):
    """
    sub\-TLV 2. Segment Routing Capability.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:ROUTER_CAPABILITY_SR_CAPABILITY"):
        super().__init__(ns, pref, tag)


class ROUTERCAPABILITYSRALGORITHM(ROUTERCAPABILITYSUBTLVSTYPE):
    """
    sub\-TLV 19. Segment Routing Algorithm.
    
    """
    _prefix = 'oc-isis-lsdb-types'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/isis-lsdb-types", pref="openconfig-isis-lsdb-types", tag="openconfig-isis-lsdb-types:ROUTER_CAPABILITY_SR_ALGORITHM"):
        super().__init__(ns, pref, tag)



